##  Server-Side Error Codes (5xx)
5xx codes indicate errors originating from the SAP LeanIX servers, suggesting system-level issues or temporary disruptions. These error codes adhere to the guidelines specified in [Section 6.6 of RFC 7231![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdatatracker.ietf.org%2Fdoc%2Fhtml%2Frfc7231%23section-6.6 "https://datatracker.ietf.org/doc/html/rfc7231#section-6.6"), the Internet Standards Track document issued by IETF.
Code | Meaning
---|---
500 (Internal Server Error) | An unexpected server-side error has occurred.
502 (Bad Gateway) | The SAP LeanIX servers received an invalid response from an upstream service.
503 (Service Unavailable) | The SAP LeanIX servers are temporarily unavailable.


YesNo
Send
